@@ -2,11 +2,13 @@
 A module containing the Bag class.
 """
 
+
 class PermissionsError(Exception):
     """
     Base class for policy violation problems.
     """
 
+
 class ForbiddenError(PermissionsError):
     """
     The provided user cannot do this action.
@@ -64,39 +66,6 @@ class Policy(object):
         self.manage = manage
         self.accept = accept
 
-    def _single_value_set(self, target_list, value):
-        return len(target_list) == 1 and target_list[0] == value
-
-    def _no_constraint(self, info_list):
-        # no constraints then all pass
-        try:
-            if len(info_list) == 0:
-                return True
-        except TypeError:
-            # constraint not set (weirdness in DB)
-            return True
-
-        return False
-
-    def _user_valid(self, user_sign, user_list):
-        # always allow if the constraint is ANY
-        if self._single_value_set(user_list, u'ANY'):
-            if user_sign != u'GUEST':
-                return True
-
-        # if the user is in the constraint list, return true
-        if user_sign in user_list:
-            return True
-
-        return False
-
-    def _role_valid(self, roles, role_list):
-        # if there is an intersection between the users roles and any roles
-        # in the constraint, return true
-        if [role for role in roles if role in role_list]:
-            return True
-        return False
-
     def allows(self, user, constraint):
         """
         Is user allowed to perform the action described
@@ -111,21 +80,21 @@ class Policy(object):
 
         info_list = self.__getattribute__(constraint)
 
-        if self._no_constraint(info_list):
+        if _no_constraint(info_list):
             return True
 
         user_list = [x for x in info_list if not x.startswith('R:')]
 
         # always reject if the constraint is NONE
-        if self._single_value_set(user_list, u'NONE'):
+        if _single_value_set(user_list, u'NONE'):
             raise ForbiddenError('%s may not %s' % (user_sign, constraint))
 
-        if self._user_valid(user_sign, user_list):
+        if _user_valid(user_sign, user_list):
             return True
 
         role_list = [x[2:] for x in info_list if x.startswith('R:')]
 
-        if self._role_valid(roles, role_list):
+        if _role_valid(roles, role_list):
             return True
 
         # if the user is set to GUEST (meaning nobody in credentials)
@@ -179,3 +148,40 @@ def create_policy_check(environ, entity, usersign):
                     'admin role required to create, user has no roles')
 
     raise ForbiddenError('create access denied')
+
+
+def _single_value_set(target_list, value):
+    return len(target_list) == 1 and target_list[0] == value
+
+
+def _no_constraint(info_list):
+    # no constraints then all pass
+    try:
+        if len(info_list) == 0:
+            return True
+    except TypeError:
+        # constraint not set (weirdness in DB)
+        return True
+
+    return False
+
+
+def _role_valid(roles, role_list):
+    # if there is an intersection between the users roles and any roles
+    # in the constraint, return true
+    if [role for role in roles if role in role_list]:
+        return True
+    return False
+
+
+def _user_valid(user_sign, user_list):
+    # always allow if the constraint is ANY
+    if _single_value_set(user_list, u'ANY'):
+        if user_sign != u'GUEST':
+            return True
+
+    # if the user is in the constraint list, return true
+    if user_sign in user_list:
+        return True
+
+    return False
